@@ -22,7 +22,7 @@ import types
 from ctypes import oledll, PyDLL, py_object, byref, POINTER, windll
 
 import pythoncom
-from win32com.client import Dispatch, CDispatch, DispatchEx
+from win32com.client import Dispatch, CoClassBaseClass, CDispatch, DispatchEx, DispatchBaseClass
 import win32timezone
 import win32gui
 import win32process
@@ -64,10 +64,9 @@ class COMRetryMethodWrapper:
         while True:
             try:
                 v = self.__method(*args, **kwargs)
-                t = type(v)
-                if t is CDispatch:
+                if isinstance(v, (CDispatch, CoClassBaseClass, DispatchBaseClass)):
                     return COMRetryObjectWrapper(v)
-                elif t is types.MethodType:
+                elif type(v) is types.MethodType:
                     return COMRetryMethodWrapper(v)
                 else:
                     return v
@@ -121,10 +120,9 @@ class COMRetryObjectWrapper:
         while True:
             try:
                 v = getattr(self._inner, item)
-                t = type(v)
-                if t is CDispatch:
+                if isinstance(v, (CDispatch, CoClassBaseClass, DispatchBaseClass)):
                     return COMRetryObjectWrapper(v)
-                elif t is types.MethodType:
+                elif type(v) is types.MethodType:
                     return COMRetryMethodWrapper(v)
                 else:
                     return v
@@ -156,10 +154,9 @@ class COMRetryObjectWrapper:
         for i in range(N_COM_ATTEMPTS + 1):
             try:
                 v = self._inner(*args, **kwargs)
-                t = type(v)
-                if t is CDispatch:
+                if isinstance(v, (CDispatch, CoClassBaseClass, DispatchBaseClass)):
                     return COMRetryObjectWrapper(v)
-                elif t is types.MethodType:
+                elif type(v) is types.MethodType:
                     return COMRetryMethodWrapper(v)
                 else:
                     return v
@@ -178,8 +175,7 @@ class COMRetryObjectWrapper:
 
     def __iter__(self):
         for v in self._inner:
-            t = type(v)
-            if t is CDispatch:
+            if isinstance(v, (CDispatch, CoClassBaseClass, DispatchBaseClass)):
                 yield COMRetryObjectWrapper(v)
             else:
                 yield v
@@ -294,7 +290,8 @@ class Apps:
 
 class App:
 
-    def __init__(self, spec=None, add_book=True, xl=None):
+    def __init__(self, spec=None, add_book=True, xl=None, visible=None):
+        # visible is only required on mac
         if spec is not None:
             warn('spec is ignored on Windows.')
         if xl is None:
